# DevGossip
**A platform that allows developers to gossip about anything.**

The platform is built using Python programming language with a myriad of modules and functions to achieve optimum result and seamless user experience.

**Features:**
* User can:
    * Signup
    * Login
    * Logout
    * Create posts anonymously.
* While logged in, user can:
    * View all posts
    * Create new posts
    * Search for specific posts
    * Comment on posts
    
**Note:** User cannot get access to features such as making and reading comments, search and viewing all published posts if user is not logged in.

**Running the application from the command line:**
* Run the following command on the command line, "pip install devgossip-praiseey"
* Run "dev-gossip"
